@@ -9,10 +9,11 @@ class PermissionError(Exception):
         self.request = request
 
 class HttpError(Exception):
-    def __init__(self, message, status, request):
+    def __init__(self, message, status, request, cause=None):
         self.message = message
         self.status = status
         self.request = request
+        self.cause = cause
 
 class RateLimitError(Exception):
     def __init__(self, message, status, request):
